Struct ep_dwt::DwtProfiler[][src]

pub struct DwtProfiler<const FREQ: u32> { /* fields omitted */ }
DWT trace unit implementing EmbeddedProfiler.

The frequency of the DWT is encoded using the parameter FREQ.

Implementations

Enable the DWT and provide a new EmbeddedProfiler.

Note that the sysclk parameter should come from e.g. the HAL’s clock generation function so the real speed and the declared speed can be compared.

Panics

asserts that the compile time constant FREQ matches the runtime provided sysclk